@@ -83,7 +83,7 @@ overlay<- function (..., rlist = NULL, prefix = NULL, sparse=FALSE){
   }else{
     S3 <- matrix(0, nrow = dim(dat2)[1], ncol = length(levo))
   }
-
+  
   rownames(S3) <- rownames(dat2)
   colnames(S3) <- levo
   for (i in 1:length(S1list)) {
@@ -105,7 +105,7 @@ overlay<- function (..., rlist = NULL, prefix = NULL, sparse=FALSE){
 }
 
 list2usmat <- function(sigmaL){
-
+  
   f <- function(n, x){
     res <- ((n*(n-1))/2 + n) - x
     if(res < 0){res <- 100}
@@ -114,7 +114,7 @@ list2usmat <- function(sigmaL){
   if(is.list(sigmaL)){
     ss <- unlist(sigmaL)
   }else{ss <- sigmaL}
-
+  
   x <- length(ss)
   n <- round(optimize(f, c(1, 50), tol = 0.0001, x=x)$minimum)
   mss <- matrix(NA,n,n)
@@ -152,7 +152,7 @@ myformula <- function(x){
 }
 
 reshape_mmer <- function(object, namelist){
-
+  
   nt <- nrow(as.matrix(object$sigma[,,1]))
   ntn <- attr(object$sigma, "dimnames")[[2]]
   nre <- length(object$U)
@@ -160,21 +160,21 @@ reshape_mmer <- function(object, namelist){
   U2 <- list()#vector("list",nre)
   VarU2 <- list()
   PevU2 <- list()
-
+  
   if(nre > 0){
     for(ire in 1:nre){
-
+      
       N <- nrow(object$U[[ire]])
       utlist <- list()# vector("list",nt)
       varutlist <- list()# vector("list",nt)
       pevutlist <- list()# vector("list",nt)
-
+      
       # pick <- numeric()
       # for(it in 1:nt){
       #   pick <- c(pick,seq(it,N,nt))
       # }
       provus <- matrix(object$U[[ire]],ncol=nt,byrow = T)
-
+      
       for(it in 1:nt){
         pick <- seq(it,N,nt)
         pit <- ntn[it]
@@ -190,27 +190,27 @@ reshape_mmer <- function(object, namelist){
           rownames(pevutlist[[ pit ]]) <- colnames(pevutlist[[ pit ]]) <- namelist[[ire]]
         }else{pevutlist[[ pit ]] <-pevutlist[[ pit ]]}
       }
-
+      
       U2[[ nren[ire] ]] <- utlist
       VarU2[[ nren[ire] ]] <- varutlist
       PevU2[[ nren[ire] ]] <- pevutlist
     }
-
+    
     object$U <- U2; U2<-NULL
     object$VarU <- VarU2; VarU2<-NULL
     object$PevU <- PevU2; PevU2<-NULL
   }
-
-
-
+  
+  
+  
   N <- nrow(object$Vi)
   pick <- numeric()
   for(it in 1:nt){
     pick <- c(pick,seq(it,N,nt))
   }
-
+  
   object$Vi <- object$Vi[pick,pick]
-
+  
   # object$constraintsF
   # object$Beta <- matrix(object$Beta,ncol=nt,byrow = F)
   # print(namelist[[length(namelist)]])
@@ -218,15 +218,15 @@ reshape_mmer <- function(object, namelist){
   # rownames(object$Beta) <- namelist[[length(namelist)]]
   object$Beta <- cbind(namelist[[length(namelist)]],object$Beta)
   colnames(object$Beta) <- c("Trait","Effect","Estimate")
-
+  
   object$fitted <- matrix(object$fitted,ncol=nt, byrow=TRUE)
   object$residuals <- matrix(object$residuals,ncol=nt, byrow = TRUE)
-
+  
   MyArray <- object$sigma
   object$sigma <- lapply(seq(dim(MyArray)[3]), function(x) MyArray[ , , x])
   object$sigma <- lapply(object$sigma,function(x){mm <- as.matrix(x);colnames(mm)<-rownames(mm) <- ntn;return(mm)})
   names(object$sigma) <- nren
-
+  
   MyArray <- object$sigma_scaled
   object$sigma_scaled <- lapply(seq(dim(MyArray)[3]), function(x) MyArray[ , , x])
   object$sigma_scaled <- lapply(object$sigma_scaled,function(x){mm <- as.matrix(x);colnames(mm)<-rownames(mm) <- ntn;return(mm)})
@@ -239,7 +239,7 @@ reshape_mmer <- function(object, namelist){
 ## na.methods
 
 subdata <- function(data,fixed,na.method.Y=NULL,na.method.X=NULL){
-
+  
   # silently change all columns that are defined as character into factors
   # columnTypes <- unlist(lapply(data, class))
   # columnTypesC <- which(columnTypes == "character")
@@ -304,7 +304,7 @@ subdata <- function(data,fixed,na.method.Y=NULL,na.method.X=NULL){
     data <- data[good,]
   }else{stop("na.method.Y not recognized")}
   data <- data.frame(data)
-
+  
   ##########
   ## na.method x
   yuyu <- strsplit(as.character(fixed[3]), split = "[+]")[[1]]
@@ -313,13 +313,13 @@ subdata <- function(data,fixed,na.method.Y=NULL,na.method.X=NULL){
   })
   xtermss2 <- apply(data.frame(xtermss),1,function(x){gsub(",.*","",expi2(x))})
   xtermss2[which(xtermss2 == "")] <- xtermss[which(xtermss2 == "")]
-
+  
   xtermss2 <- intersect(colnames(data),xtermss2) # only focus on the terms that are in teh dataset so we can skip overlay and weird vs structures
-
+  
   # print(xtermss2)
   if(length(xtermss2) > 0){
     mycl <- as.vector(unlist(lapply(data.frame(data[,xtermss2]),class)))
-
+    
     if(na.method.X=="include"){
       touse <- xtermss2
       for(i in 1:length(touse)){
@@ -346,9 +346,9 @@ subdata <- function(data,fixed,na.method.Y=NULL,na.method.X=NULL){
     }else{stop("na.method.Y not recognized")}
     data <- data.frame(data)
   }
-
+  
   return(list(datar=data,good=good))
-
+  
 }
 
 ##############
@@ -535,7 +535,8 @@ redmm <- function (x, M = NULL, Lam=NULL, nPC=50, cholD=FALSE, returnLam=FALSE)
   }else{return(Zstar)}
   
 }
-rrc <- function(timevar=NULL, idvar=NULL, response=NULL, Gu=NULL, nPC=2, returnLam=FALSE, cholD=TRUE){
+rrc <- function(timevar=NULL, idvar=NULL, response=NULL, 
+                Gu=NULL, nPC=2, returnGamma=FALSE, cholD=TRUE){
   if(is.null(timevar)){stop("Please provide the timevar argument.", call. = FALSE)}
   if(is.null(idvar)){stop("Please provide the idvar argument.", call. = FALSE)}
   if(is.null(response)){stop("Please provide the response argument.", call. = FALSE)}
@@ -567,37 +568,38 @@ rrc <- function(timevar=NULL, idvar=NULL, response=NULL, Gu=NULL, nPC=2, returnL
   }
   ##
   Y <- apply(wide,2, sommer::imputev)
-  GE <- cov(scale(Y, scale = TRUE, center = TRUE)) # surrogate of unstructured matrix to start with
-  GE <- as.matrix(nearPD(GE)$mat)
+  Sigma <- cov(scale(Y, scale = TRUE, center = TRUE)) # surrogate of unstructured matrix to start with
+  Sigma <- as.matrix(nearPD(Sigma)$mat)
   # GE <- as.data.frame(t(scale( t(scale(Y, center=T,scale=F)), center=T, scale=F)))  # sum(GE^2)
   if(cholD){
-    ## OPTION 2. USING CHOLESKY
-    Lam <- t(chol(GE)); # LOADINGS  # same GE=LL' from cholesky  plot(unlist(Lam%*%t(Lam)), unlist(GE))
+  ## OPTION 2. USING CHOLESKY
+  Gamma <- t(chol(Sigma)); # LOADINGS  # same GE=LL' from cholesky  plot(unlist(Gamma%*%t(Gamma)), unlist(GE))
   }else{
     ## OPTION 1. USING SVD
-    U <- svd(GE)$u;  # V <- svd(GE)$v
-    D <- diag(svd(GE)$d)
-    Lam <- U %*% sqrt(D); # LOADINGS 
+    U <- svd(Sigma)$u;  # V <- svd(GE)$v
+    D <- diag(svd(Sigma)$d)
+    Gamma <- U %*% sqrt(D); # LOADINGS
+    rownames(Gamma) <- colnames(Gamma) <- rownames(Sigma)
   }
-  colnamesLam <- colnames(Lam)
-  rownamesLam <- rownames(Lam)
-  Lam <- as.matrix(Lam[,1:nPC]); 
-  colnames(Lam) <- colnamesLam[1:nPC]
-  rownames(Lam) <- rownamesLam
+  colnamesGamma <- colnames(Gamma)
+  rownamesGamma <- rownames(Gamma)
+  Gamma <- as.matrix(Gamma[,1:nPC]); 
+  colnames(Gamma) <- colnamesGamma[1:nPC]
+  rownames(Gamma) <- rownamesGamma
   ##
-  rownames(Lam) <- gsub("v.names_","",rownames(Lam))#rownames(GE)#levels(dataset$Genotype);  # rownames(Se) <- colnames(GE)#levels(dataset$Environment)
-  colnames(Lam) <- paste("PC", 1:ncol(Lam), sep =""); # 
+  rownames(Gamma) <- gsub("v.names_","",rownames(Gamma))#rownames(GE)#levels(dataset$Genotype);  # rownames(Se) <- colnames(GE)#levels(dataset$Environment)
+  colnames(Gamma) <- paste("PC", 1:ncol(Gamma), sep =""); # 
   ######### GEreduced = Sg %*% t(Se) 
   # if we want to merge with PCs for environments
   dtx$index <- 1:nrow(dtx)
   dtx2 <- dtx[which(!is.na(dtx$v.names)),]
   Z <- Matrix::sparse.model.matrix(~timevar -1, na.action = na.pass, data=dtx2)
   colnames(Z) <- gsub("timevar","",colnames(Z))
-  Z <- Z%*%Lam[colnames(Z),] # we multiple original Z by the LOADINGS
+  Z <- Z%*%Gamma[colnames(Z),] # we multiple original Z by the LOADINGS
   Z <- as.matrix(Z)
   rownames(Z) <- NULL
-  if(returnLam){
-    return(list(Lam=Lam, wide=wide))
+  if(returnGamma){
+    return(list(Gamma=Gamma, wide=wide))
   }else{
     return(Z)
   }
@@ -823,27 +825,27 @@ fcm <- function(x, reps=NULL){
 }
 
 bivariateRun <- function(model, n.core=1){
-
+  
   args <- model[[length(model)]]
-
+  
   if(!args$return.param){
     stop("The model provided needs to have the return.param argument set to TRUE. \nPlease read the documentation of the bivariateRun function carefully.\n", call. = FALSE)
   }
-
+  
   response <- strsplit(as.character(args$fixed[2]), split = "[+]")[[1]]
   expi <- function(j){gsub("[\\(\\)]", "", regmatches(j, gregexpr("\\(.*?\\)", j))[[1]])}
   expi2 <- function(x){gsub("(?<=\\()[^()]*(?=\\))(*SKIP)(*F)|.", "", x, perl=T)}
   traits <- trimws(strsplit(expi(response),",")[[1]])
-
+  
   combos <- expand.grid(traits,traits)
   combos <- combos[which(combos[,1] != combos[,2]),];
   combos <- combos[!duplicated(t(apply(combos, 1, sort))),];rownames(combos) <- NULL
-
+  
   RHS <- as.character(args$fixed[3])
   it <- as.list(1:nrow(combos))
-
+  
   cat(paste(nrow(combos), "bivariate models to be run\n"))
-
+  
   model.results <- parallel::mclapply(it,
                                       function(x) {
                                         # score.calc(M[ix.pheno, markers])
@@ -860,13 +862,13 @@ bivariateRun <- function(model, n.core=1){
                                         p1 <- gsub("diag\\([[:digit:]])","diag(2)",p1)
                                         p1 <- gsub("uncm\\([[:digit:]])","uncm(2)",p1)
                                         args2$rcov <- as.formula(paste(p1[1],paste(p1[-1],collapse = "+")))
-
+                                        
                                         gsub("[1-9]","k",as.character(args2$random))
                                         res0 <- do.call(mmer, args=args2)
                                         return(res0)
                                       },
                                       mc.cores = n.core)
-
+  
   sigmas <- lapply(model.results, function(x){x$sigma})
   sigmas_scaled <- lapply(model.results, function(x){x$sigma_scaled})
   nre <- length(sigmas[[1]])
@@ -886,7 +888,7 @@ bivariateRun <- function(model, n.core=1){
     sigmaslist[[namesre[i]]] <- mt
     sigmas_scaledlist[[namesre[i]]] <- mts
   }
-
+  
   names(model.results) <- apply(combos,1,function(x){paste(x,collapse = "-")})
   # corlist <- lapply(sigmaslist,cov2cor)
   final <- list(sigmas=sigmaslist, sigmas_scaled=sigmas_scaledlist, models=model.results)
